Class: Aws::WAF::Types::GeoMatchSetSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAF::Types::GeoMatchSetSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-waf/types.rb
Overview
<note markdown=“1”> This is **AWS WAF Classic** documentation. For more information, see
- AWS WAF Classic][1
-
in the developer guide.
**For the latest version of AWS WAF**, use the AWS WAFV2 API and see
the [AWS WAF Developer Guide]. With the latest version, AWS WAF has a single set of endpoints for regional and global use.
</note>
Contains the identifier and the name of the GeoMatchSet.
[1]: docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#geo_match_set_id ⇒ String
The
GeoMatchSetIdfor an GeoMatchSet. -
#name ⇒ String
A friendly name or description of the GeoMatchSet.
Instance Attribute Details
#geo_match_set_id ⇒ String
The GeoMatchSetId for an GeoMatchSet. You can use GeoMatchSetId in a GetGeoMatchSet request to get detailed information about an GeoMatchSet.
1777 1778 1779 1780 1781 1782 |
# File 'lib/aws-sdk-waf/types.rb', line 1777 class GeoMatchSetSummary < Struct.new( :geo_match_set_id, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A friendly name or description of the GeoMatchSet. You can’t change the name of an GeoMatchSet after you create it.
1777 1778 1779 1780 1781 1782 |
# File 'lib/aws-sdk-waf/types.rb', line 1777 class GeoMatchSetSummary < Struct.new( :geo_match_set_id, :name) SENSITIVE = [] include Aws::Structure end |