Class: Aws::WAF::Types::HTTPHeader

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-waf/types.rb

Overview

<note markdown=“1”> This is **AWS WAF Classic** documentation. For more information, see

AWS WAF Classic][1

in the developer guide.

**For the latest version of AWS WAF**, use the AWS WAFV2 API and see

the [AWS WAF Developer Guide]. With the latest version, AWS WAF has a single set of endpoints for regional and global use.

</note>

The response from a GetSampledRequests request includes an HTTPHeader complex type that appears as Headers in the response syntax. HTTPHeader contains the names and values of all of the headers that appear in one of the web requests that were returned by GetSampledRequests.

[1]: docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of one of the headers in the sampled web request.

Returns:

  • (String)


2450
2451
2452
2453
2454
2455
# File 'lib/aws-sdk-waf/types.rb', line 2450

class HTTPHeader < Struct.new(
  :name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The value of one of the headers in the sampled web request.

Returns:

  • (String)


2450
2451
2452
2453
2454
2455
# File 'lib/aws-sdk-waf/types.rb', line 2450

class HTTPHeader < Struct.new(
  :name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end