Class: Aws::WAF::Types::ListActivatedRulesInRuleGroupResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAF::Types::ListActivatedRulesInRuleGroupResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-waf/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activated_rules ⇒ Array<Types::ActivatedRule>
An array of
ActivatedRulesobjects. -
#next_marker ⇒ String
If you have more
ActivatedRulesthan the number that you specified forLimitin the request, the response includes aNextMarkervalue.
Instance Attribute Details
#activated_rules ⇒ Array<Types::ActivatedRule>
An array of ActivatedRules objects.
2773 2774 2775 2776 2777 2778 |
# File 'lib/aws-sdk-waf/types.rb', line 2773 class ListActivatedRulesInRuleGroupResponse < Struct.new( :next_marker, :activated_rules) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
If you have more ActivatedRules than the number that you specified for Limit in the request, the response includes a NextMarker value. To list more ActivatedRules, submit another ListActivatedRulesInRuleGroup request, and specify the NextMarker value from the response in the NextMarker value in the next request.
2773 2774 2775 2776 2777 2778 |
# File 'lib/aws-sdk-waf/types.rb', line 2773 class ListActivatedRulesInRuleGroupResponse < Struct.new( :next_marker, :activated_rules) SENSITIVE = [] include Aws::Structure end |