Class: Aws::WAF::Types::ListGeoMatchSetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAF::Types::ListGeoMatchSetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-waf/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#limit ⇒ Integer
Specifies the number of
GeoMatchSetobjects that you want AWS WAF to return for this request. -
#next_marker ⇒ String
If you specify a value for
Limitand you have more ‘GeoMatchSet`s than the value ofLimit, AWS WAF returns aNextMarkervalue in the response that allows you to list another group ofGeoMatchSetobjects.
Instance Attribute Details
#limit ⇒ Integer
Specifies the number of GeoMatchSet objects that you want AWS WAF to return for this request. If you have more GeoMatchSet objects than the number you specify for Limit, the response includes a NextMarker value that you can use to get another batch of GeoMatchSet objects.
2847 2848 2849 2850 2851 2852 |
# File 'lib/aws-sdk-waf/types.rb', line 2847 class ListGeoMatchSetsRequest < Struct.new( :next_marker, :limit) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
If you specify a value for Limit and you have more ‘GeoMatchSet`s than the value of Limit, AWS WAF returns a NextMarker value in the response that allows you to list another group of GeoMatchSet objects. For the second and subsequent ListGeoMatchSets requests, specify the value of NextMarker from the previous response to get information about another batch of GeoMatchSet objects.
2847 2848 2849 2850 2851 2852 |
# File 'lib/aws-sdk-waf/types.rb', line 2847 class ListGeoMatchSetsRequest < Struct.new( :next_marker, :limit) SENSITIVE = [] include Aws::Structure end |