Class: Aws::WAF::Types::ListIPSetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAF::Types::ListIPSetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-waf/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#limit ⇒ Integer
Specifies the number of
IPSetobjects that you want AWS WAF to return for this request. -
#next_marker ⇒ String
AWS WAF returns a
NextMarkervalue in the response that allows you to list another group ofIPSets.
Instance Attribute Details
#limit ⇒ Integer
Specifies the number of IPSet objects that you want AWS WAF to return for this request. If you have more IPSet objects than the number you specify for Limit, the response includes a NextMarker value that you can use to get another batch of IPSet objects.
2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-waf/types.rb', line 2893 class ListIPSetsRequest < Struct.new( :next_marker, :limit) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
AWS WAF returns a NextMarker value in the response that allows you to list another group of IPSets. For the second and subsequent ListIPSets requests, specify the value of NextMarker from the previous response to get information about another batch of IPSets.
2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-waf/types.rb', line 2893 class ListIPSetsRequest < Struct.new( :next_marker, :limit) SENSITIVE = [] include Aws::Structure end |