Class: Aws::WAF::Types::ListRegexMatchSetsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAF::Types::ListRegexMatchSetsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-waf/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_marker ⇒ String
If you have more
RegexMatchSetobjects than the number that you specified forLimitin the request, the response includes aNextMarkervalue. -
#regex_match_sets ⇒ Array<Types::RegexMatchSetSummary>
An array of RegexMatchSetSummary objects.
Instance Attribute Details
#next_marker ⇒ String
If you have more RegexMatchSet objects than the number that you specified for Limit in the request, the response includes a NextMarker value. To list more RegexMatchSet objects, submit another ListRegexMatchSets request, and specify the NextMarker value from the response in the NextMarker value in the next request.
3056 3057 3058 3059 3060 3061 |
# File 'lib/aws-sdk-waf/types.rb', line 3056 class ListRegexMatchSetsResponse < Struct.new( :next_marker, :regex_match_sets) SENSITIVE = [] include Aws::Structure end |
#regex_match_sets ⇒ Array<Types::RegexMatchSetSummary>
An array of RegexMatchSetSummary objects.
3056 3057 3058 3059 3060 3061 |
# File 'lib/aws-sdk-waf/types.rb', line 3056 class ListRegexMatchSetsResponse < Struct.new( :next_marker, :regex_match_sets) SENSITIVE = [] include Aws::Structure end |