Class: Aws::WAF::Types::ListRegexPatternSetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAF::Types::ListRegexPatternSetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-waf/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#limit ⇒ Integer
Specifies the number of
RegexPatternSetobjects that you want AWS WAF to return for this request. -
#next_marker ⇒ String
If you specify a value for
Limitand you have moreRegexPatternSetobjects than the value ofLimit, AWS WAF returns aNextMarkervalue in the response that allows you to list another group ofRegexPatternSetobjects.
Instance Attribute Details
#limit ⇒ Integer
Specifies the number of RegexPatternSet objects that you want AWS WAF to return for this request. If you have more RegexPatternSet objects than the number you specify for Limit, the response includes a NextMarker value that you can use to get another batch of RegexPatternSet objects.
3083 3084 3085 3086 3087 3088 |
# File 'lib/aws-sdk-waf/types.rb', line 3083 class ListRegexPatternSetsRequest < Struct.new( :next_marker, :limit) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
If you specify a value for Limit and you have more RegexPatternSet objects than the value of Limit, AWS WAF returns a NextMarker value in the response that allows you to list another group of RegexPatternSet objects. For the second and subsequent ListRegexPatternSets requests, specify the value of NextMarker from the previous response to get information about another batch of RegexPatternSet objects.
3083 3084 3085 3086 3087 3088 |
# File 'lib/aws-sdk-waf/types.rb', line 3083 class ListRegexPatternSetsRequest < Struct.new( :next_marker, :limit) SENSITIVE = [] include Aws::Structure end |