Class: Aws::WAF::Types::ListRuleGroupsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAF::Types::ListRuleGroupsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-waf/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_marker ⇒ String
If you have more
RuleGroupsthan the number that you specified forLimitin the request, the response includes aNextMarkervalue. -
#rule_groups ⇒ Array<Types::RuleGroupSummary>
An array of RuleGroup objects.
Instance Attribute Details
#next_marker ⇒ String
If you have more RuleGroups than the number that you specified for Limit in the request, the response includes a NextMarker value. To list more RuleGroups, submit another ListRuleGroups request, and specify the NextMarker value from the response in the NextMarker value in the next request.
3151 3152 3153 3154 3155 3156 |
# File 'lib/aws-sdk-waf/types.rb', line 3151 class ListRuleGroupsResponse < Struct.new( :next_marker, :rule_groups) SENSITIVE = [] include Aws::Structure end |
#rule_groups ⇒ Array<Types::RuleGroupSummary>
An array of RuleGroup objects.
3151 3152 3153 3154 3155 3156 |
# File 'lib/aws-sdk-waf/types.rb', line 3151 class ListRuleGroupsResponse < Struct.new( :next_marker, :rule_groups) SENSITIVE = [] include Aws::Structure end |