Class: Aws::WAF::Types::ListXssMatchSetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAF::Types::ListXssMatchSetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-waf/types.rb
Overview
A request to list the XssMatchSet objects created by the current AWS account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#limit ⇒ Integer
Specifies the number of XssMatchSet objects that you want AWS WAF to return for this request.
-
#next_marker ⇒ String
If you specify a value for
Limitand you have more XssMatchSet objects than the value ofLimit, AWS WAF returns aNextMarkervalue in the response that allows you to list another group ofXssMatchSets.
Instance Attribute Details
#limit ⇒ Integer
Specifies the number of XssMatchSet objects that you want AWS WAF to return for this request. If you have more XssMatchSet objects than the number you specify for Limit, the response includes a NextMarker value that you can use to get another batch of Rules.
3457 3458 3459 3460 3461 3462 |
# File 'lib/aws-sdk-waf/types.rb', line 3457 class ListXssMatchSetsRequest < Struct.new( :next_marker, :limit) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
If you specify a value for Limit and you have more XssMatchSet objects than the value of Limit, AWS WAF returns a NextMarker value in the response that allows you to list another group of XssMatchSets. For the second and subsequent ListXssMatchSets requests, specify the value of NextMarker from the previous response to get information about another batch of XssMatchSets.
3457 3458 3459 3460 3461 3462 |
# File 'lib/aws-sdk-waf/types.rb', line 3457 class ListXssMatchSetsRequest < Struct.new( :next_marker, :limit) SENSITIVE = [] include Aws::Structure end |