Class: Aws::WAF::Types::LoggingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAF::Types::LoggingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-waf/types.rb
Overview
<note markdown=“1”> This is **AWS WAF Classic** documentation. For more information, see
- AWS WAF Classic][1
-
in the developer guide.
**For the latest version of AWS WAF**, use the AWS WAFV2 API and see
the [AWS WAF Developer Guide]. With the latest version, AWS WAF has a single set of endpoints for regional and global use.
</note>
The Amazon Kinesis Data Firehose, RedactedFields information, and the web ACL Amazon Resource Name (ARN).
[1]: docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_destination_configs ⇒ Array<String>
An array of Amazon Kinesis Data Firehose ARNs.
-
#redacted_fields ⇒ Array<Types::FieldToMatch>
The parts of the request that you want redacted from the logs.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the web ACL that you want to associate with
LogDestinationConfigs.
Instance Attribute Details
#log_destination_configs ⇒ Array<String>
An array of Amazon Kinesis Data Firehose ARNs.
3522 3523 3524 3525 3526 3527 3528 |
# File 'lib/aws-sdk-waf/types.rb', line 3522 class LoggingConfiguration < Struct.new( :resource_arn, :log_destination_configs, :redacted_fields) SENSITIVE = [] include Aws::Structure end |
#redacted_fields ⇒ Array<Types::FieldToMatch>
The parts of the request that you want redacted from the logs. For example, if you redact the cookie field, the cookie field in the firehose will be xxx.
3522 3523 3524 3525 3526 3527 3528 |
# File 'lib/aws-sdk-waf/types.rb', line 3522 class LoggingConfiguration < Struct.new( :resource_arn, :log_destination_configs, :redacted_fields) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the web ACL that you want to associate with LogDestinationConfigs.
3522 3523 3524 3525 3526 3527 3528 |
# File 'lib/aws-sdk-waf/types.rb', line 3522 class LoggingConfiguration < Struct.new( :resource_arn, :log_destination_configs, :redacted_fields) SENSITIVE = [] include Aws::Structure end |