Class: Aws::WAF::Types::RuleGroupSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-waf/types.rb

Overview

<note markdown=“1”> This is **AWS WAF Classic** documentation. For more information, see

AWS WAF Classic][1

in the developer guide.

**For the latest version of AWS WAF**, use the AWS WAFV2 API and see

the [AWS WAF Developer Guide]. With the latest version, AWS WAF has a single set of endpoints for regional and global use.

</note>

Contains the identifier and the friendly name or description of the RuleGroup.

[1]: docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

A friendly name or description of the RuleGroup. You can’t change the name of a RuleGroup after you create it.

Returns:

  • (String)


4296
4297
4298
4299
4300
4301
# File 'lib/aws-sdk-waf/types.rb', line 4296

class RuleGroupSummary < Struct.new(
  :rule_group_id,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#rule_group_idString

A unique identifier for a RuleGroup. You use RuleGroupId to get more information about a RuleGroup (see GetRuleGroup), update a RuleGroup (see UpdateRuleGroup), insert a RuleGroup into a WebACL or delete one from a WebACL (see UpdateWebACL), or delete a RuleGroup from AWS WAF (see DeleteRuleGroup).

RuleGroupId is returned by CreateRuleGroup and by ListRuleGroups.

Returns:

  • (String)


4296
4297
4298
4299
4300
4301
# File 'lib/aws-sdk-waf/types.rb', line 4296

class RuleGroupSummary < Struct.new(
  :rule_group_id,
  :name)
  SENSITIVE = []
  include Aws::Structure
end