Class: Aws::WAF::Types::RuleSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-waf/types.rb

Overview

<note markdown=“1”> This is **AWS WAF Classic** documentation. For more information, see

AWS WAF Classic][1

in the developer guide.

**For the latest version of AWS WAF**, use the AWS WAFV2 API and see

the [AWS WAF Developer Guide]. With the latest version, AWS WAF has a single set of endpoints for regional and global use.

</note>

Contains the identifier and the friendly name or description of the Rule.

[1]: docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

A friendly name or description of the Rule. You can’t change the name of a Rule after you create it.

Returns:

  • (String)


4375
4376
4377
4378
4379
4380
# File 'lib/aws-sdk-waf/types.rb', line 4375

class RuleSummary < Struct.new(
  :rule_id,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#rule_idString

A unique identifier for a Rule. You use RuleId to get more information about a Rule (see GetRule), update a Rule (see UpdateRule), insert a Rule into a WebACL or delete one from a WebACL (see UpdateWebACL), or delete a Rule from AWS WAF (see DeleteRule).

RuleId is returned by CreateRule and by ListRules.

Returns:

  • (String)


4375
4376
4377
4378
4379
4380
# File 'lib/aws-sdk-waf/types.rb', line 4375

class RuleSummary < Struct.new(
  :rule_id,
  :name)
  SENSITIVE = []
  include Aws::Structure
end