Class: Aws::WAF::Types::SampledHTTPRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-waf/types.rb

Overview

<note markdown=“1”> This is **AWS WAF Classic** documentation. For more information, see

AWS WAF Classic][1

in the developer guide.

**For the latest version of AWS WAF**, use the AWS WAFV2 API and see

the [AWS WAF Developer Guide]. With the latest version, AWS WAF has a single set of endpoints for regional and global use.

</note>

The response from a GetSampledRequests request includes a SampledHTTPRequests complex type that appears as SampledRequests in the response syntax. SampledHTTPRequests contains one SampledHTTPRequest object for each web request that is returned by GetSampledRequests.

[1]: docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action for the Rule that the request matched: ALLOW, BLOCK, or COUNT.

Returns:

  • (String)


4468
4469
4470
4471
4472
4473
4474
4475
4476
# File 'lib/aws-sdk-waf/types.rb', line 4468

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_within_rule_group)
  SENSITIVE = []
  include Aws::Structure
end

#requestTypes::HTTPRequest

A complex type that contains detailed information about the request.

Returns:



4468
4469
4470
4471
4472
4473
4474
4475
4476
# File 'lib/aws-sdk-waf/types.rb', line 4468

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_within_rule_group)
  SENSITIVE = []
  include Aws::Structure
end

#rule_within_rule_groupString

This value is returned if the GetSampledRequests request specifies the ID of a RuleGroup rather than the ID of an individual rule. RuleWithinRuleGroup is the rule within the specified RuleGroup that matched the request listed in the response.

Returns:

  • (String)


4468
4469
4470
4471
4472
4473
4474
4475
4476
# File 'lib/aws-sdk-waf/types.rb', line 4468

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_within_rule_group)
  SENSITIVE = []
  include Aws::Structure
end

#timestampTime

The time at which AWS WAF received the request from your AWS resource, in Unix time format (in seconds).

Returns:

  • (Time)


4468
4469
4470
4471
4472
4473
4474
4475
4476
# File 'lib/aws-sdk-waf/types.rb', line 4468

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_within_rule_group)
  SENSITIVE = []
  include Aws::Structure
end

#weightInteger

A value that indicates how one result in the response relates proportionally to other results in the response. A result that has a weight of 2 represents roughly twice as many CloudFront web requests as a result that has a weight of 1.

Returns:

  • (Integer)


4468
4469
4470
4471
4472
4473
4474
4475
4476
# File 'lib/aws-sdk-waf/types.rb', line 4468

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_within_rule_group)
  SENSITIVE = []
  include Aws::Structure
end