Class: Aws::WAF::Types::SizeConstraintSetSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAF::Types::SizeConstraintSetSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-waf/types.rb
Overview
<note markdown=“1”> This is **AWS WAF Classic** documentation. For more information, see
- AWS WAF Classic][1
-
in the developer guide.
**For the latest version of AWS WAF**, use the AWS WAFV2 API and see
the [AWS WAF Developer Guide]. With the latest version, AWS WAF has a single set of endpoints for regional and global use.
</note>
The Id and Name of a SizeConstraintSet.
[1]: docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the
SizeConstraintSet, if any. -
#size_constraint_set_id ⇒ String
A unique identifier for a
SizeConstraintSet.
Instance Attribute Details
#name ⇒ String
The name of the SizeConstraintSet, if any.
4721 4722 4723 4724 4725 4726 |
# File 'lib/aws-sdk-waf/types.rb', line 4721 class SizeConstraintSetSummary < Struct.new( :size_constraint_set_id, :name) SENSITIVE = [] include Aws::Structure end |
#size_constraint_set_id ⇒ String
A unique identifier for a SizeConstraintSet. You use SizeConstraintSetId to get information about a SizeConstraintSet (see GetSizeConstraintSet), update a SizeConstraintSet (see UpdateSizeConstraintSet), insert a SizeConstraintSet into a Rule or delete one from a Rule (see UpdateRule), and delete a SizeConstraintSet from AWS WAF (see DeleteSizeConstraintSet).
SizeConstraintSetId is returned by CreateSizeConstraintSet and by ListSizeConstraintSets.
4721 4722 4723 4724 4725 4726 |
# File 'lib/aws-sdk-waf/types.rb', line 4721 class SizeConstraintSetSummary < Struct.new( :size_constraint_set_id, :name) SENSITIVE = [] include Aws::Structure end |