Class: Aws::WAF::Types::UpdateByteMatchSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAF::Types::UpdateByteMatchSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-waf/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#byte_match_set_id ⇒ String
The
ByteMatchSetIdof the ByteMatchSet that you want to update. -
#change_token ⇒ String
The value returned by the most recent call to GetChangeToken.
-
#updates ⇒ Array<Types::ByteMatchSetUpdate>
An array of
ByteMatchSetUpdateobjects that you want to insert into or delete from a ByteMatchSet.
Instance Attribute Details
#byte_match_set_id ⇒ String
The ByteMatchSetId of the ByteMatchSet that you want to update. ByteMatchSetId is returned by CreateByteMatchSet and by ListByteMatchSets.
5261 5262 5263 5264 5265 5266 5267 |
# File 'lib/aws-sdk-waf/types.rb', line 5261 class UpdateByteMatchSetRequest < Struct.new( :byte_match_set_id, :change_token, :updates) SENSITIVE = [] include Aws::Structure end |
#change_token ⇒ String
The value returned by the most recent call to GetChangeToken.
5261 5262 5263 5264 5265 5266 5267 |
# File 'lib/aws-sdk-waf/types.rb', line 5261 class UpdateByteMatchSetRequest < Struct.new( :byte_match_set_id, :change_token, :updates) SENSITIVE = [] include Aws::Structure end |
#updates ⇒ Array<Types::ByteMatchSetUpdate>
An array of ByteMatchSetUpdate objects that you want to insert into or delete from a ByteMatchSet. For more information, see the applicable data types:
-
ByteMatchSetUpdate: Contains
ActionandByteMatchTuple -
ByteMatchTuple: Contains
FieldToMatch,PositionalConstraint,TargetString, andTextTransformation -
FieldToMatch: Contains
DataandType
5261 5262 5263 5264 5265 5266 5267 |
# File 'lib/aws-sdk-waf/types.rb', line 5261 class UpdateByteMatchSetRequest < Struct.new( :byte_match_set_id, :change_token, :updates) SENSITIVE = [] include Aws::Structure end |