Class: Aws::WAF::Types::UpdateGeoMatchSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-waf/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#change_tokenString

The value returned by the most recent call to GetChangeToken.



5309
5310
5311
5312
5313
5314
5315
# File 'lib/aws-sdk-waf/types.rb', line 5309

class UpdateGeoMatchSetRequest < Struct.new(
  :geo_match_set_id,
  :change_token,
  :updates)
  SENSITIVE = []
  include Aws::Structure
end

#geo_match_set_idString

The GeoMatchSetId of the GeoMatchSet that you want to update. GeoMatchSetId is returned by CreateGeoMatchSet and by ListGeoMatchSets.



5309
5310
5311
5312
5313
5314
5315
# File 'lib/aws-sdk-waf/types.rb', line 5309

class UpdateGeoMatchSetRequest < Struct.new(
  :geo_match_set_id,
  :change_token,
  :updates)
  SENSITIVE = []
  include Aws::Structure
end

#updatesArray<Types::GeoMatchSetUpdate>

An array of GeoMatchSetUpdate objects that you want to insert into or delete from an GeoMatchSet. For more information, see the applicable data types:

  • GeoMatchSetUpdate: Contains Action and GeoMatchConstraint

  • GeoMatchConstraint: Contains Type and Value

    You can have only one Type and Value per GeoMatchConstraint. To add multiple countries, include multiple GeoMatchSetUpdate objects in your request.



5309
5310
5311
5312
5313
5314
5315
# File 'lib/aws-sdk-waf/types.rb', line 5309

class UpdateGeoMatchSetRequest < Struct.new(
  :geo_match_set_id,
  :change_token,
  :updates)
  SENSITIVE = []
  include Aws::Structure
end