Class: Aws::WAF::Types::UpdateRuleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAF::Types::UpdateRuleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-waf/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#change_token ⇒ String
The value returned by the most recent call to GetChangeToken.
-
#rule_id ⇒ String
The
RuleIdof theRulethat you want to update. -
#updates ⇒ Array<Types::RuleUpdate>
An array of
RuleUpdateobjects that you want to insert into or delete from a Rule.
Instance Attribute Details
#change_token ⇒ String
The value returned by the most recent call to GetChangeToken.
5573 5574 5575 5576 5577 5578 5579 |
# File 'lib/aws-sdk-waf/types.rb', line 5573 class UpdateRuleRequest < Struct.new( :rule_id, :change_token, :updates) SENSITIVE = [] include Aws::Structure end |
#rule_id ⇒ String
The RuleId of the Rule that you want to update. RuleId is returned by CreateRule and by ListRules.
5573 5574 5575 5576 5577 5578 5579 |
# File 'lib/aws-sdk-waf/types.rb', line 5573 class UpdateRuleRequest < Struct.new( :rule_id, :change_token, :updates) SENSITIVE = [] include Aws::Structure end |
#updates ⇒ Array<Types::RuleUpdate>
An array of RuleUpdate objects that you want to insert into or delete from a Rule. For more information, see the applicable data types:
-
RuleUpdate: Contains
ActionandPredicate -
Predicate: Contains
DataId,Negated, andType -
FieldToMatch: Contains
DataandType
5573 5574 5575 5576 5577 5578 5579 |
# File 'lib/aws-sdk-waf/types.rb', line 5573 class UpdateRuleRequest < Struct.new( :rule_id, :change_token, :updates) SENSITIVE = [] include Aws::Structure end |