Class: Aws::WAF::Types::WAFEntityMigrationException
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAF::Types::WAFEntityMigrationException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-waf/types.rb
Overview
The operation failed due to a problem with the migration. The failure cause is provided in the exception, in the MigrationErrorType:
-
ENTITY_NOT_SUPPORTED- The web ACL has an unsupported entity but theIgnoreUnsupportedTypeis not set to true. -
ENTITY_NOT_FOUND- The web ACL doesn’t exist. -
S3_BUCKET_NO_PERMISSION- You don’t have permission to perform thePutObjectaction to the specified Amazon S3 bucket. -
S3_BUCKET_NOT_ACCESSIBLE- The bucket policy doesn’t allow AWS WAF to perform thePutObjectaction in the bucket. -
S3_BUCKET_NOT_FOUND- The S3 bucket doesn’t exist. -
S3_BUCKET_INVALID_REGION- The S3 bucket is not in the same Region as the web ACL. -
S3_INTERNAL_ERROR- AWS WAF failed to create the template in the S3 bucket for another reason.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
5862 5863 5864 5865 5866 5867 5868 |
# File 'lib/aws-sdk-waf/types.rb', line 5862 class WAFEntityMigrationException < Struct.new( :message, :migration_error_type, :migration_error_reason) SENSITIVE = [] include Aws::Structure end |
#migration_error_reason ⇒ String
5862 5863 5864 5865 5866 5867 5868 |
# File 'lib/aws-sdk-waf/types.rb', line 5862 class WAFEntityMigrationException < Struct.new( :message, :migration_error_type, :migration_error_reason) SENSITIVE = [] include Aws::Structure end |
#migration_error_type ⇒ String
5862 5863 5864 5865 5866 5867 5868 |
# File 'lib/aws-sdk-waf/types.rb', line 5862 class WAFEntityMigrationException < Struct.new( :message, :migration_error_type, :migration_error_reason) SENSITIVE = [] include Aws::Structure end |