Class: Aws::WAF::Types::WAFInvalidPermissionPolicyException
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAF::Types::WAFInvalidPermissionPolicyException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-waf/types.rb
Overview
The operation failed because the specified policy is not in the proper format.
The policy is subject to the following restrictions:
-
You can attach only one policy with each
PutPermissionPolicyrequest. -
The policy must include an
Effect,ActionandPrincipal. -
Effectmust specifyAllow. -
The
Actionin the policy must bewaf:UpdateWebACL,waf-regional:UpdateWebACL,waf:GetRuleGroupandwaf-regional:GetRuleGroup. Any extra or wildcard actions in the policy will be rejected. -
The policy cannot include a
Resourceparameter. -
The ARN in the request must be a valid WAF RuleGroup ARN and the RuleGroup must exist in the same region.
-
The user making the request must be the owner of the RuleGroup.
-
Your policy must be composed using IAM Policy version 2012-10-17.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
5997 5998 5999 6000 6001 |
# File 'lib/aws-sdk-waf/types.rb', line 5997 class WAFInvalidPermissionPolicyException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |