Class: Aws::WAF::Types::WebACL
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAF::Types::WebACL
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-waf/types.rb
Overview
<note markdown=“1”> This is **AWS WAF Classic** documentation. For more information, see
- AWS WAF Classic][1
-
in the developer guide.
**For the latest version of AWS WAF**, use the AWS WAFV2 API and see
the [AWS WAF Developer Guide]. With the latest version, AWS WAF has a single set of endpoints for regional and global use.
</note>
Contains the Rules that identify the requests that you want to allow, block, or count. In a WebACL, you also specify a default action (ALLOW or BLOCK), and the action for each Rule that you add to a WebACL, for example, block requests from specified IP addresses or block requests from specified referrers. You also associate the WebACL with a CloudFront distribution to identify the requests that you want AWS WAF to filter. If you add more than one Rule to a WebACL, a request needs to match only one of the specifications to be allowed, blocked, or counted. For more information, see UpdateWebACL.
[1]: docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_action ⇒ Types::WafAction
The action to perform if none of the
Rulescontained in theWebACLmatch. -
#metric_name ⇒ String
A friendly name or description for the metrics for this
WebACL. -
#name ⇒ String
A friendly name or description of the
WebACL. -
#rules ⇒ Array<Types::ActivatedRule>
An array that contains the action for each
Rulein aWebACL, the priority of theRule, and the ID of theRule. -
#web_acl_arn ⇒ String
Tha Amazon Resource Name (ARN) of the web ACL.
-
#web_acl_id ⇒ String
A unique identifier for a
WebACL.
Instance Attribute Details
#default_action ⇒ Types::WafAction
The action to perform if none of the Rules contained in the WebACL match. The action is specified by the WafAction object.
6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-waf/types.rb', line 6329 class WebACL < Struct.new( :web_acl_id, :name, :metric_name, :default_action, :rules, :web_acl_arn) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
A friendly name or description for the metrics for this WebACL. The name can contain only alphanumeric characters (A-Z, a-z, 0-9), with maximum length 128 and minimum length one. It can’t contain whitespace or metric names reserved for AWS WAF, including “All” and “Default_Action.” You can’t change MetricName after you create the WebACL.
6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-waf/types.rb', line 6329 class WebACL < Struct.new( :web_acl_id, :name, :metric_name, :default_action, :rules, :web_acl_arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A friendly name or description of the WebACL. You can’t change the name of a WebACL after you create it.
6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-waf/types.rb', line 6329 class WebACL < Struct.new( :web_acl_id, :name, :metric_name, :default_action, :rules, :web_acl_arn) SENSITIVE = [] include Aws::Structure end |
#rules ⇒ Array<Types::ActivatedRule>
An array that contains the action for each Rule in a WebACL, the priority of the Rule, and the ID of the Rule.
6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-waf/types.rb', line 6329 class WebACL < Struct.new( :web_acl_id, :name, :metric_name, :default_action, :rules, :web_acl_arn) SENSITIVE = [] include Aws::Structure end |
#web_acl_arn ⇒ String
Tha Amazon Resource Name (ARN) of the web ACL.
6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-waf/types.rb', line 6329 class WebACL < Struct.new( :web_acl_id, :name, :metric_name, :default_action, :rules, :web_acl_arn) SENSITIVE = [] include Aws::Structure end |
#web_acl_id ⇒ String
A unique identifier for a WebACL. You use WebACLId to get information about a WebACL (see GetWebACL), update a WebACL (see UpdateWebACL), and delete a WebACL from AWS WAF (see DeleteWebACL).
WebACLId is returned by CreateWebACL and by ListWebACLs.
6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-waf/types.rb', line 6329 class WebACL < Struct.new( :web_acl_id, :name, :metric_name, :default_action, :rules, :web_acl_arn) SENSITIVE = [] include Aws::Structure end |