Class: Aws::WAF::Types::XssMatchSet

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-waf/types.rb

Overview

<note markdown=“1”> This is **AWS WAF Classic** documentation. For more information, see

AWS WAF Classic][1

in the developer guide.

**For the latest version of AWS WAF**, use the AWS WAFV2 API and see

the [AWS WAF Developer Guide]. With the latest version, AWS WAF has a single set of endpoints for regional and global use.

</note>

A complex type that contains XssMatchTuple objects, which specify the parts of web requests that you want AWS WAF to inspect for cross-site scripting attacks and, if you want AWS WAF to inspect a header, the name of the header. If a XssMatchSet contains more than one XssMatchTuple object, a request needs to include cross-site scripting attacks in only one of the specified parts of the request to be considered a match.

[1]: docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name, if any, of the XssMatchSet.

Returns:

  • (String)


6461
6462
6463
6464
6465
6466
6467
# File 'lib/aws-sdk-waf/types.rb', line 6461

class XssMatchSet < Struct.new(
  :xss_match_set_id,
  :name,
  :xss_match_tuples)
  SENSITIVE = []
  include Aws::Structure
end

#xss_match_set_idString

A unique identifier for an XssMatchSet. You use XssMatchSetId to get information about an XssMatchSet (see GetXssMatchSet), update an XssMatchSet (see UpdateXssMatchSet), insert an XssMatchSet into a Rule or delete one from a Rule (see UpdateRule), and delete an XssMatchSet from AWS WAF (see DeleteXssMatchSet).

XssMatchSetId is returned by CreateXssMatchSet and by ListXssMatchSets.

Returns:

  • (String)


6461
6462
6463
6464
6465
6466
6467
# File 'lib/aws-sdk-waf/types.rb', line 6461

class XssMatchSet < Struct.new(
  :xss_match_set_id,
  :name,
  :xss_match_tuples)
  SENSITIVE = []
  include Aws::Structure
end

#xss_match_tuplesArray<Types::XssMatchTuple>

Specifies the parts of web requests that you want to inspect for cross-site scripting attacks.

Returns:



6461
6462
6463
6464
6465
6466
6467
# File 'lib/aws-sdk-waf/types.rb', line 6461

class XssMatchSet < Struct.new(
  :xss_match_set_id,
  :name,
  :xss_match_tuples)
  SENSITIVE = []
  include Aws::Structure
end