Class: Aws::WAF::Types::XssMatchSetSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAF::Types::XssMatchSetSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-waf/types.rb
Overview
<note markdown=“1”> This is **AWS WAF Classic** documentation. For more information, see
- AWS WAF Classic][1
-
in the developer guide.
**For the latest version of AWS WAF**, use the AWS WAFV2 API and see
the [AWS WAF Developer Guide]. With the latest version, AWS WAF has a single set of endpoints for regional and global use.
</note>
The Id and Name of an XssMatchSet.
[1]: docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the
XssMatchSet, if any, specified byId. -
#xss_match_set_id ⇒ String
A unique identifier for an
XssMatchSet.
Instance Attribute Details
#name ⇒ String
The name of the XssMatchSet, if any, specified by Id.
6502 6503 6504 6505 6506 6507 |
# File 'lib/aws-sdk-waf/types.rb', line 6502 class XssMatchSetSummary < Struct.new( :xss_match_set_id, :name) SENSITIVE = [] include Aws::Structure end |
#xss_match_set_id ⇒ String
A unique identifier for an XssMatchSet. You use XssMatchSetId to get information about a XssMatchSet (see GetXssMatchSet), update an XssMatchSet (see UpdateXssMatchSet), insert an XssMatchSet into a Rule or delete one from a Rule (see UpdateRule), and delete an XssMatchSet from AWS WAF (see DeleteXssMatchSet).
XssMatchSetId is returned by CreateXssMatchSet and by ListXssMatchSets.
6502 6503 6504 6505 6506 6507 |
# File 'lib/aws-sdk-waf/types.rb', line 6502 class XssMatchSetSummary < Struct.new( :xss_match_set_id, :name) SENSITIVE = [] include Aws::Structure end |