Class: Aws::WAF::Types::ByteMatchSetUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAF::Types::ByteMatchSetUpdate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-waf/types.rb
Overview
<note markdown=“1”> This is **AWS WAF Classic** documentation. For more information, see
- AWS WAF Classic][1
-
in the developer guide.
**For the latest version of AWS WAF**, use the AWS WAFV2 API and see
the [AWS WAF Developer Guide]. With the latest version, AWS WAF has a single set of endpoints for regional and global use.
</note>
In an UpdateByteMatchSet request, ByteMatchSetUpdate specifies whether to insert or delete a ByteMatchTuple and includes the settings for the ByteMatchTuple.
[1]: docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
Specifies whether to insert or delete a ByteMatchTuple.
-
#byte_match_tuple ⇒ Types::ByteMatchTuple
Information about the part of a web request that you want AWS WAF to inspect and the value that you want AWS WAF to search for.
Instance Attribute Details
#action ⇒ String
Specifies whether to insert or delete a ByteMatchTuple.
293 294 295 296 297 298 |
# File 'lib/aws-sdk-waf/types.rb', line 293 class ByteMatchSetUpdate < Struct.new( :action, :byte_match_tuple) SENSITIVE = [] include Aws::Structure end |
#byte_match_tuple ⇒ Types::ByteMatchTuple
Information about the part of a web request that you want AWS WAF to inspect and the value that you want AWS WAF to search for. If you specify DELETE for the value of Action, the ByteMatchTuple values must exactly match the values in the ByteMatchTuple that you want to delete from the ByteMatchSet.
293 294 295 296 297 298 |
# File 'lib/aws-sdk-waf/types.rb', line 293 class ByteMatchSetUpdate < Struct.new( :action, :byte_match_tuple) SENSITIVE = [] include Aws::Structure end |