Class: Aws::WAF::Types::IPSet
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAF::Types::IPSet
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-waf/types.rb
Overview
<note markdown=“1”> This is **AWS WAF Classic** documentation. For more information, see
- AWS WAF Classic][1
-
in the developer guide.
**For the latest version of AWS WAF**, use the AWS WAFV2 API and see
the [AWS WAF Developer Guide]. With the latest version, AWS WAF has a single set of endpoints for regional and global use.
</note>
Contains one or more IP addresses or blocks of IP addresses specified in Classless Inter-Domain Routing (CIDR) notation. AWS WAF supports IPv4 address ranges: /8 and any range between /16 through /32. AWS WAF supports IPv6 address ranges: /24, /32, /48, /56, /64, and /128.
To specify an individual IP address, you specify the four-part IP address followed by a /32, for example, 192.0.2.0/32. To block a range of IP addresses, you can specify /8 or any range between /16 through /32 (for IPv4) or /24, /32, /48, /56, /64, or /128 (for IPv6). For more information about CIDR notation, see the Wikipedia entry [Classless Inter-Domain Routing].
[1]: docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html [3]: en.wikipedia.org/wiki/Classless_Inter-Domain_Routing
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ip_set_descriptors ⇒ Array<Types::IPSetDescriptor>
The IP address type (
IPV4orIPV6) and the IP address range (in CIDR notation) that web requests originate from. -
#ip_set_id ⇒ String
The
IPSetIdfor anIPSet. -
#name ⇒ String
A friendly name or description of the IPSet.
Instance Attribute Details
#ip_set_descriptors ⇒ Array<Types::IPSetDescriptor>
The IP address type (IPV4 or IPV6) and the IP address range (in CIDR notation) that web requests originate from. If the WebACL is associated with a CloudFront distribution and the viewer did not use an HTTP proxy or a load balancer to send the request, this is the value of the c-ip field in the CloudFront access logs.
2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-waf/types.rb', line 2585 class IPSet < Struct.new( :ip_set_id, :name, :ip_set_descriptors) SENSITIVE = [] include Aws::Structure end |
#ip_set_id ⇒ String
The IPSetId for an IPSet. You use IPSetId to get information about an IPSet (see GetIPSet), update an IPSet (see UpdateIPSet), insert an IPSet into a Rule or delete one from a Rule (see UpdateRule), and delete an IPSet from AWS WAF (see DeleteIPSet).
IPSetId is returned by CreateIPSet and by ListIPSets.
2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-waf/types.rb', line 2585 class IPSet < Struct.new( :ip_set_id, :name, :ip_set_descriptors) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A friendly name or description of the IPSet. You can’t change the name of an IPSet after you create it.
2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-waf/types.rb', line 2585 class IPSet < Struct.new( :ip_set_id, :name, :ip_set_descriptors) SENSITIVE = [] include Aws::Structure end |