Class: Aws::WAF::Types::ListRulesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAF::Types::ListRulesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-waf/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_marker ⇒ String
If you have more
Rulesthan the number that you specified forLimitin the request, the response includes aNextMarkervalue. -
#rules ⇒ Array<Types::RuleSummary>
An array of RuleSummary objects.
Instance Attribute Details
#next_marker ⇒ String
If you have more Rules than the number that you specified for Limit in the request, the response includes a NextMarker value. To list more Rules, submit another ListRules request, and specify the NextMarker value from the response in the NextMarker value in the next request.
3197 3198 3199 3200 3201 3202 |
# File 'lib/aws-sdk-waf/types.rb', line 3197 class ListRulesResponse < Struct.new( :next_marker, :rules) SENSITIVE = [] include Aws::Structure end |
#rules ⇒ Array<Types::RuleSummary>
An array of RuleSummary objects.
3197 3198 3199 3200 3201 3202 |
# File 'lib/aws-sdk-waf/types.rb', line 3197 class ListRulesResponse < Struct.new( :next_marker, :rules) SENSITIVE = [] include Aws::Structure end |